/* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
/* Balsa E-Mail Client
 *
 * Copyright (C) 1997-2019 Stuart Parmenter and others,
 *                         See the file AUTHORS for a list.
 *
 * Rubrica2 address book support was written by Copyright (C)
 * Albrecht Dre <albrecht.dress@arcor.de> 2007.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option) 
 * any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Rubrica address book ...
 */

#ifndef __LIBBALSA_ADDRESS_BOOK_RUBRICA_H__
#define __LIBBALSA_ADDRESS_BOOK_RUBRICA_H__

#include "address-book-text.h"

#define LIBBALSA_TYPE_ADDRESS_BOOK_RUBRICA libbalsa_address_book_rubrica_get_type()
G_DECLARE_FINAL_TYPE(LibBalsaAddressBookRubrica, libbalsa_address_book_rubrica,
                     LIBBALSA, ADDRESS_BOOK_RUBRICA, LibBalsaAddressBookText)

LibBalsaAddressBook *libbalsa_address_book_rubrica_new(const gchar * name,
						       const gchar * path);

#endif				/* __LIBBALSA_ADDRESS_BOOK_RUBRICA_H__ */
